


dbstat(l)                 LINCKS System                 dbstat(l)



NAME
     dbstat - retrieve status of a LINCKS database

SYNOPSIS
     dbstat [ _d_a_t_a_b_a_s_e-_d_i_r ]

DESCRIPTION
     Prints out the status of a  LINCKS  database.   Such  status
     includes  the socket on which it communicates, which machine
     the database servers are running  on,  the  database  owner,
     size  of  the  object  identifiers  (4  or  8  bytes), using
     encrypted or clear text passwords, and whether  the  monitor
     and the netserv process are running or not.

OPTIONS
     database-dir
          The directory  holding  the  database  files.   If  not
          given,  the  environment  variable LINCKSDBDIR is used.
          This option overrides the environment variable.

FILES
     DBDIR/.lincksrc
          Database Configuration File

ENVIRONMENT
     _L_I_N_C_K_S_D_B_D_I_R
          specifies the default LINCKS database directory.

SEE ALSO
     lincks(l), dbs(l), netserv(l), monitor(l), xlincks(l)

DIAGNOSTICS
     None.  Simply prints out the status of the database.

BUGS
     No  known  bugs.   Please  report  all   bugs   to   lincks-
     bugs@ida.liu.se.   Please  include  a description of how you
     can reproduce the bug and the output of either  `dbx  dbstat
     core' or `gdb dbstat core' if possible.

COPYRIGHT
     Copyright (C) 1993, 1994 Lin Padgham, Ralph Ronnquist

     The collective LINCKS programs are free  software;  you  can
     redistribute  them and/or modify them under the terms of the
     GNU General Public License as published by the Free Software
     Foundation, version 2.

     The collective LINCKS programs are distributed in  the  hope
     that  they will be useful, but WITHOUT ANY WARRANTY; without
     even the implied warranty of MERCHANTABILITY or FITNESS  FOR
     A  PARTICULAR  PURPOSE.   See the GNU General Public License



IISLAB                Last change: 5/27/94                      1






dbstat(l)                 LINCKS System                 dbstat(l)



     for more details.

     You should have received a copy of the  GNU  General  Public
     License  along with the LINCKS system; see the file COPYING.
     If not, write to the Free Software Foundation, 675 Mass Ave,
     Cambridge, MA 02139, USA.

AVAILABILITY
     The most recently released version of the LINCKS  system  is
     always  available  for  anonymous  ftp  from  ftp.ida.liu.se
     (130.236.30.131) in the directory pub/lincks.












































IISLAB                Last change: 5/27/94                      2



