.\" 
.\" Linkoping Intelligent Communication of Knowledge System (LINCKS)
.\"      Copyright (C) 1993, 1994 Lin Padgham, Ralph Rönnquist
.\"       Department of Computer and Information Sciences
.\"		University of Linkoping, Sweden
.\"		    581 83 Linkoping, Sweden
.\"		       lincks@ida.liu.se
.\"
.\" These collective LINCKS programs are free software; you can 
.\" redistribute them and/or modify them under the terms of the GNU
.\" General Public License as published by the Free Software Foundation,
.\" version 2 of the License.
.\"
.\" These programs are distributed in the hope that they will be useful,
.\" but WITHOUT ANY WARRANTY; without even the implied warranty of
.\" MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
.\" GNU General Public License for more details.
.\"
.\" You should have received a copy of the GNU General Public License
.\" along with the programs; if not, write to the Free Software
.\" Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
.\"
.\" netserv man page
.\" author: David Partain
.\" version:  @(#)netserv.l	1.7 5/27/94
.\"
.TH netserv l "5/27/94" IISLAB "LINCKS System"
.SH NAME
netserv - LINCKS database network server
.SH SYNOPSIS
.B netserv
[
-d
] 
[
-h \fIhostname\fR
]
.B database-dir
.SH DESCRIPTION
\fInetserv\fR awaits requests from applications
(\fIxlincks\fR) to connect to the database, at which point it spawns a
\fIdbs\fR process to perform communication between the workspace and the
database.  There is one \fInetserv\fR process per database.

As a general rule, the user should never have to start \fInetserv\fR.
Instead, all database control should be done with the \fIlincks\fR
program.
.SH OPTIONS
.TP
.B \-d
Run \fInetserv\fR in debug mode.
.TP
.B \-h \fIhostname\fR
The host running the monitor program.
.TP
.B database-dir
The directory with the database files.
.SH FILES
.TP
.B DBDIR/.lincksrc
Database Configuration File.
.TP
.B DBDIR/passwd
Database password file read by \fInetserv\fR at login.
.TP
.B DBDIR/groups
Groups permissions file read by monitor to see if a user has access to a
particular object.
.TP
.B DBDIR/wrgroups
Groups permissions file read by monitor to see if a user has write
access to a particular object. Used only if it exists, 
else (write) access is based solely on the groups file.
.TP
.B LOGDIR/netserv.log
Where netserv log and error messages are logged.
.TP
.B /tmp/lincks.log
Last Resort log file if LOGDIR isn't writable or doesn't exist.
.SH SEE ALSO
dbs(l), lincks(l), monitor(l)
.SH DIAGNOSTICS
Log and error messages are logged to LOGDIR/netserv.log.  LOGDIR is set
in DBDIR/.lincksrc.
.SH BUGS
No known bugs.  Please report all bugs to lincks-bugs@ida.liu.se.
Please include a description of how you can reproduce the bug and the
output of either `dbx netserv core' or `gdb netserv core' if possible.
.SH COPYRIGHT
Copyright (C) 1993, 1994 Lin Padgham, Ralph Ronnquist
.LP
The collective LINCKS programs are free software; you can redistribute 
them and/or modify them under the terms of the GNU General Public
License as published by the Free Software Foundation, version 2.
.LP
The collective LINCKS programs are distributed in the hope that they
will be useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
the GNU General Public License for more details.
.LP
You should have received a copy of the GNU General Public License along
with the LINCKS system; see the file COPYING.  If not, write to the Free Software
Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
.SH AVAILABILITY
The most recently released version of the LINCKS system is always 
available for anonymous ftp from ftp.ida.liu.se (130.236.30.131) in
the directory pub/lincks.
