.\" 
.\" Linkoping Intelligent Communication of Knowledge System (LINCKS)
.\"      Copyright (C) 1993, 1994 Lin Padgham, Ralph Rönnquist
.\"       Department of Computer and Information Sciences
.\"		University of Linkoping, Sweden
.\"		    581 83 Linkoping, Sweden
.\"		       lincks@ida.liu.se
.\"
.\" These collective LINCKS programs are free software; you can 
.\" redistribute them and/or modify them under the terms of the GNU
.\" General Public License as published by the Free Software Foundation,
.\" version 2 of the License.
.\"
.\" These programs are distributed in the hope that they will be useful,
.\" but WITHOUT ANY WARRANTY; without even the implied warranty of
.\" MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
.\" GNU General Public License for more details.
.\"
.\" You should have received a copy of the GNU General Public License
.\" along with the programs; if not, write to the Free Software
.\" Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
.\"
.\" monitor man page
.\" author: David Partain
.\" version:  @(#)monitor.l	1.5 5/19/94
.\"
.TH monitor l "5/19/94" IISLAB "LINCKS System"

.SH NAME
monitor - LINCKS database monitor
.SH SYNOPSIS
.B monitor
[
.B \-d
]
.B database-dir
.SH DESCRIPTION
The \fImonitor\fR program is responsible for the management of the
LINCKS database files. It starts up the \fInetserv\fR process, reads and
writes in
the various database files, and registers the appropriate
functions with the RPC service package.  There is one \fI
monitor\fR per database.
It has several RPC functions available that are
called by the database server processes (\fIdbs\fR) to retrieve information on
where database information is stored. The \fImonitor\fR program itself
never touches the contents of the data files, although it is
responsible for creating new data and molecule files when the need
arises (the current files get too large).  \fIdatabase-dir\fR is a full path
name specifying which database to run.

A user should never have to manually start this program, but rather the
monitor should be start with \fIlincks\fR (see lincks(l)).
.SH OPTIONS
.TP
.B \-d
Run the monitor in debug mode.
.TP
.B database-dir
The directory where the database files reside.  This argument is
required.
.SH FILES
.TP
.B DBDIR/.lincksrc
Database Configuration File.
.TP
.B LOGDIR/monitor.log
Log file for error messages.  LOGDIR is set in DBDIR/.lincksrc.
.TP
.B /tmp/lincks.log
Last Resort log file if LOGDIR doesn't exist or isn't writable.
.SH SEE ALSO
dbs(l), lincks(l), netserv(l)
.SH DIAGNOSTICS
We hope that the information logged in \fImonitor.log\fR will be useful
in diagnosing any problems.
.SH BUGS
No known bugs.  Please report all bugs to lincks-bugs@ida.liu.se.
Please include a description of how you can reproduce the bug and the
output of either `dbx monitor core' or `gdb monitor core' if possible.
.SH COPYRIGHT
Copyright (C) 1993, 1994 Lin Padgham, Ralph Ronnquist
.LP
The collective LINCKS programs are free software; you can redistribute
them and/or modify them under the terms of the GNU General Public
License as published by the Free Software Foundation, version 2.
.LP
The collective LINCKS programs are distributed in the hope that they
will be useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
the GNU General Public License for more details.
.LP
You should have received a copy of the GNU General Public License along
with the LINCKS system; see the file COPYING.  If not, write to the Free Software
Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
.SH AVAILABILITY
The most recently released version of the LINCKS system is always 
available for anonymous ftp from ftp.ida.liu.se (130.236.30.131) in
the directory pub/lincks.
