.\"
.\" Linkoping Intelligent Communication of Knowledge System (LINCKS)
.\"      Copyright (C) 1993, 1994 Lin Padgham, Ralph Rönnquist
.\"       Department of Computer and Information Sciences
.\"		University of Linkoping, Sweden
.\"		    581 83 Linkoping, Sweden
.\"		       lincks@ida.liu.se
.\"
.\" These collective LINCKS programs are free software; you can 
.\" redistribute them and/or modify them under the terms of the GNU
.\" General Public License as published by the Free Software Foundation,
.\" version 2 of the License.
.\"
.\" These programs are distributed in the hope that they will be useful,
.\" but WITHOUT ANY WARRANTY; without even the implied warranty of
.\" MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
.\" GNU General Public License for more details.
.\"
.\" You should have received a copy of the GNU General Public License
.\" along with the programs; if not, write to the Free Software
.\" Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
.\"
.\"
.\" cutoff man page
.\" author: David Partain
.\" version:  @(#)cutoff.l	1.7 5/19/94
.\"
.TH cutoff l "5/19/94" IISLAB "LINCKS System"
.SH NAME
cutoff - LINCKS database garbage collection program
.SH SYNOPSIS
.B cutoff
.SH DESCRIPTION
\fIcutoff\fR is used to do garbage collection a LINCKS database.  The
average LINCKS user should not use this program.  Please consult the
database administrator instead if you want to compact the database.

That being said, the steps are:

Stop the database system.  
.sp
.in +5
\fIlincks -k DBDIR\fR
.in -5
.sp
See \fIlincks(l)\fR for more information.

Move into the database directory (\fIDBDIR\fR) and create a directory
called \fIArchive\fR.  Copy (not move) all of the files in \fIDBDIR\fR
into \fIArchive\fR.  Thereafter, start \fIcutoff\fR from the database
directory.
.sp
.in +5
\fIcd DBDIR\fR
.sp
\fImkdir Archive\fR
.sp
\fIcp * Archive/\fR
.sp
\fIcutoff\fR
.in -5
.sp
The \fIArchive\fR files will not be altered in any way.  After verifying
that the database is in good shape after running \fIcutoff\fR, you can
do with this directory as you will.

Be warned that \fIcutoff\fR takes quite a long time to run, so don't do
this at a time when the database will be needed.  Also, do \fInot\fR
stop \fIcutoff\fR while it is running.  The results are
non-deterministic (in other words, it might create a royal mess).

After \fIcutoff\fR has finished, restart the database server.
.sp
.in +5
\fIlincks -s DBDIR\fR
.in -5
.SH OPTIONS
\fIcutoff\fR takes no command-line arguments.
.SH FILES
DBDIR/Archive
.SH SEE ALSO
lincks(l)
.SH DIAGNOSTICS
Some trace messages while running...
.SH BUGS
No known bugs.  The program is somewhat primitive, but there are 
no known bugs.  Please report all bugs to lincks-bugs@ida.liu.se.
Please include a description of how you can reproduce the bug and the
output of either `dbx cutoff core' or `gdb cutoff core' if possible.
.SH COPYRIGHT
Copyright (C) 1993, 1994 Lin Padgham, Ralph Ronnquist
.LP
The collective LINCKS programs are free software; you can redistribute 
them and/or modify them under the terms of the GNU General Public
License as published by the Free Software Foundation, version 2.
.LP
The collective LINCKS programs are distributed in the hope that they
will be useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
the GNU General Public License for more details.
.LP
You should have received a copy of the GNU General Public License along
with the LINCKS system; see the file COPYING.  If not, write to the
Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
.SH AVAILABILITY
The most recently released version of the LINCKS system is always 
available for anonymous ftp from ftp.ida.liu.se (130.236.30.131) in
the directory pub/lincks.
