


cutoff(l)                 LINCKS System                 cutoff(l)



NAME
     cutoff - LINCKS database garbage collection program

SYNOPSIS
     cutoff

DESCRIPTION
     _c_u_t_o_f_f is used to do garbage collection a  LINCKS  database.
     The average LINCKS user should not use this program.  Please
     consult the database administrator instead if  you  want  to
     compact the database.

     That being said, the steps are:

     Stop the database system.

          _l_i_n_c_k_s -_k _D_B_D_I_R

     See _l_i_n_c_k_s(_l) for more information.

     Move into the database directory (_D_B_D_I_R) and create a direc-
     tory  called  _A_r_c_h_i_v_e.   Copy (not move) all of the files in
     _D_B_D_I_R into _A_r_c_h_i_v_e.  Thereafter, start _c_u_t_o_f_f from the data-
     base directory.

          _c_d _D_B_D_I_R

          _m_k_d_i_r _A_r_c_h_i_v_e

          _c_p * _A_r_c_h_i_v_e/

          _c_u_t_o_f_f

     The _A_r_c_h_i_v_e files will not be altered  in  any  way.   After
     verifying  that  the database is in good shape after running
     _c_u_t_o_f_f, you can do with this directory as you will.

     Be warned that _c_u_t_o_f_f takes quite a long  time  to  run,  so
     don't  do  this  at a time when the database will be needed.
     Also, do _n_o_t stop _c_u_t_o_f_f while it is running.   The  results
     are  non-deterministic  (in  other  words, it might create a
     royal mess).

     After _c_u_t_o_f_f has finished, restart the database server.

          _l_i_n_c_k_s -_s _D_B_D_I_R

OPTIONS
     _c_u_t_o_f_f takes no command-line arguments.

FILES
     DBDIR/Archive



IISLAB                Last change: 5/19/94                      1






cutoff(l)                 LINCKS System                 cutoff(l)



SEE ALSO
     lincks(l)

DIAGNOSTICS
     Some trace messages while running...

BUGS
     No known bugs.  The program is somewhat primitive, but there
     are  no  known  bugs.   Please  report  all  bugs to lincks-
     bugs@ida.liu.se.  Please include a description  of  how  you
     can  reproduce  the bug and the output of either `dbx cutoff
     core' or `gdb cutoff core' if possible.

COPYRIGHT
     Copyright (C) 1993, 1994 Lin Padgham, Ralph Ronnquist

     The collective LINCKS programs are free  software;  you  can
     redistribute  them and/or modify them under the terms of the
     GNU General Public License as published by the Free Software
     Foundation, version 2.

     The collective LINCKS programs are distributed in  the  hope
     that  they will be useful, but WITHOUT ANY WARRANTY; without
     even the implied warranty of MERCHANTABILITY or FITNESS  FOR
     A  PARTICULAR  PURPOSE.   See the GNU General Public License
     for more details.

     You should have received a copy of the  GNU  General  Public
     License  along with the LINCKS system; see the file COPYING.
     If not, write to the Free Software Foundation, 675 Mass Ave,
     Cambridge, MA 02139, USA.

AVAILABILITY
     The most recently released version of the LINCKS  system  is
     always  available  for  anonymous  ftp  from  ftp.ida.liu.se
     (130.236.30.131) in the directory pub/lincks.



















IISLAB                Last change: 5/19/94                      2



