.\" 
.\" Linkoping Intelligent Communication of Knowledge System (LINCKS)
.\"      Copyright (C) 1993, 1994 Lin Padgham, Ralph Rönnquist
.\"       Department of Computer and Information Sciences
.\"		University of Linkoping, Sweden
.\"		    581 83 Linkoping, Sweden
.\"		       lincks@ida.liu.se
.\"
.\" These collective LINCKS programs are free software; you can 
.\" redistribute them and/or modify them under the terms of the GNU
.\" General Public License as published by the Free Software Foundation,
.\" version 2 of the License.
.\"
.\" These programs are distributed in the hope that they will be useful,
.\" but WITHOUT ANY WARRANTY; without even the implied warranty of
.\" MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
.\" GNU General Public License for more details.
.\"
.\" You should have received a copy of the GNU General Public License
.\" along with the programs; if not, write to the Free Software
.\" Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
.\"
.\" dbstat man page
.\" author: David Partain
.\" version:  @(#)dbstat.l	1.9 5/27/94
.\"
.TH dbstat l "5/27/94" IISLAB "LINCKS System"
.SH NAME
dbstat - retrieve status of a LINCKS database
.SH SYNOPSIS
dbstat [ \fIdatabase-dir\fR ]
.SH DESCRIPTION
Prints out the status of a LINCKS database.  Such status includes the
socket on which it communicates, which machine the database servers are
running on, the database owner, size of the object identifiers (4 or 8 bytes),
using encrypted or clear text passwords, and whether the monitor and 
the netserv process are running or not.
.SH OPTIONS
.TP
.B database-dir
The directory holding the database files.  If not given, the environment
variable LINCKSDBDIR is used.  This option overrides the environment
variable.
.SH FILES
.TP
.B DBDIR/.lincksrc
Database Configuration File
.SH ENVIRONMENT
.TP
.B \fILINCKSDBDIR\fR
specifies the default LINCKS database directory.
.SH SEE ALSO
lincks(l), dbs(l), netserv(l), monitor(l), xlincks(l)
.SH DIAGNOSTICS
None.  Simply prints out the status of the database.
.SH BUGS
No known bugs.  Please report all bugs to lincks-bugs@ida.liu.se.
Please include a description of how you can reproduce the bug and the
output of either `dbx dbstat core' or `gdb dbstat core' if possible.
.SH COPYRIGHT
Copyright (C) 1993, 1994 Lin Padgham, Ralph Ronnquist
.LP
The collective LINCKS programs are free software; you can redistribute 
them and/or modify them under the terms of the GNU General Public
License as published by the Free Software Foundation, version 2.
.LP
The collective LINCKS programs are distributed in the hope that they
will be useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
the GNU General Public License for more details.
.LP
You should have received a copy of the GNU General Public License along
with the LINCKS system; see the file COPYING.  If not, write to the
Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
.SH AVAILABILITY
The most recently released version of the LINCKS system is always 
available for anonymous ftp from ftp.ida.liu.se (130.236.30.131) in
the directory pub/lincks.
