


netserv(l)                LINCKS System                netserv(l)



NAME
     netserv - LINCKS database network server

SYNOPSIS
     netserv [ -d ] [ -h _h_o_s_t_n_a_m_e ] database-dir

DESCRIPTION
     _n_e_t_s_e_r_v awaits requests from applications (_x_l_i_n_c_k_s) to  con-
     nect to the database, at which point it spawns a _d_b_s process
     to perform communication between the workspace and the data-
     base.  There is one _n_e_t_s_e_r_v process per database.

     As a general rule, the user should never have to start  _n_e_t_-
     _s_e_r_v.  Instead, all database control should be done with the
     _l_i_n_c_k_s program.

OPTIONS
     -d   Run _n_e_t_s_e_r_v in debug mode.

     -h _h_o_s_t_n_a_m_e
          The host running the monitor program.

     database-dir
          The directory with the database files.

FILES
     DBDIR/.lincksrc
          Database Configuration File.

     DBDIR/passwd
          Database password file read by _n_e_t_s_e_r_v at login.

     DBDIR/groups
          Groups permissions file read by monitor  to  see  if  a
          user has access to a particular object.

     DBDIR/wrgroups
          Groups permissions file read by monitor  to  see  if  a
          user has write access to a particular object. Used only
          if it exists, else (write) access is  based  solely  on
          the groups file.

     LOGDIR/netserv.log
          Where netserv log and error messages are logged.

     /tmp/lincks.log
          Last Resort  log  file  if  LOGDIR  isn't  writable  or
          doesn't exist.

SEE ALSO
     dbs(l), lincks(l), monitor(l)




IISLAB                Last change: 5/27/94                      1






netserv(l)                LINCKS System                netserv(l)



DIAGNOSTICS
     Log and error messages  are  logged  to  LOGDIR/netserv.log.
     LOGDIR is set in DBDIR/.lincksrc.

BUGS
     No  known  bugs.   Please  report  all   bugs   to   lincks-
     bugs@ida.liu.se.   Please  include  a description of how you
     can reproduce the bug and the output of either `dbx  netserv
     core' or `gdb netserv core' if possible.

COPYRIGHT
     Copyright (C) 1993, 1994 Lin Padgham, Ralph Ronnquist

     The collective LINCKS programs are free  software;  you  can
     redistribute  them and/or modify them under the terms of the
     GNU General Public License as published by the Free Software
     Foundation, version 2.

     The collective LINCKS programs are distributed in  the  hope
     that  they will be useful, but WITHOUT ANY WARRANTY; without
     even the implied warranty of MERCHANTABILITY or FITNESS  FOR
     A  PARTICULAR  PURPOSE.   See the GNU General Public License
     for more details.

     You should have received a copy of the  GNU  General  Public
     License  along with the LINCKS system; see the file COPYING.
     If not, write to the Free Software Foundation, 675 Mass Ave,
     Cambridge, MA 02139, USA.

AVAILABILITY
     The most recently released version of the LINCKS  system  is
     always  available  for  anonymous  ftp  from  ftp.ida.liu.se
     (130.236.30.131) in the directory pub/lincks.






















IISLAB                Last change: 5/27/94                      2



