.\" 
.\" Linkoping Intelligent Communication of Knowledge System (LINCKS)
.\"      Copyright (C) 1993, 1994 Lin Padgham, Ralph Rönnquist
.\"       Department of Computer and Information Sciences
.\"		University of Linkoping, Sweden
.\"		    581 83 Linkoping, Sweden
.\"		       lincks@ida.liu.se
.\"
.\" These collective LINCKS programs are free software; you can 
.\" redistribute them and/or modify them under the terms of the GNU
.\" General Public License as published by the Free Software Foundation,
.\" version 2 of the License.
.\"
.\" These programs are distributed in the hope that they will be useful,
.\" but WITHOUT ANY WARRANTY; without even the implied warranty of
.\" MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
.\" GNU General Public License for more details.
.\"
.\" You should have received a copy of the GNU General Public License
.\" along with the programs; if not, write to the Free Software
.\" Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
.\"
.\" dbpasswd man page
.\" author: David Partain
.\" version:  @(#)dbpasswd.l	1.3 5/19/94
.\"
.TH dbpasswd l "5/19/94" IISLAB "LINCKS System"
.SH NAME
dbpasswd - change a password for a user of the LINCKS system

.SH SYNOPSIS
.B dbpasswd [-s] [-d \fIdatabase-directory\fR] username
.SH DESCRIPTION
The \fIdbpasswd\fR program is used to change the password of a current
user of the LINCKS database system.

.SH OPTIONS
.TP
.B -d \fIdatabase-directory\fR
the path to the directory holding the database files for the database.
If not given, \fIdbpasswd\fR will try to use the environment variable
LINCKSDBDIR.  This option, however, will override LINCKSDBDIR.
.TP
.B -s
silent operation.  No output will be sent to stdout or stderr unless it
is a serious error condition.
.TP
.B username
This is not optional.  The username of the person changing his/her
password.

.SH DIAGNOSTICS
Spits out a bit of information when there is an unrecoverable error
condition.  The diagnostics should be self explanatory.
.SH BUGS
No known bugs.  Please report all bugs to lincks-bugs@ida.liu.se.
Please include a description of how you can reproduce the bug and the
output of either `dbx dbpasswd core' or `gdb dbpasswd core' if possible.
.SH COPYRIGHT
Copyright (C) 1993, 1994 Martin Sjolin
.LP
The collective LINCKS programs are free software; you can redistribute 
them and/or modify them under the terms of the GNU General Public
License as published by the Free Software Foundation, version 2.
.LP
The collective LINCKS programs are distributed in the hope that they
will be useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
the GNU General Public License for more details.
.LP
You should have received a copy of the GNU General Public License along
with the LINCKS system; see the file COPYING.  If not, write to the
Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
.SH AVAILABILITY
The most recently released version of the LINCKS system is always 
available for anonymous ftp from ftp.ida.liu.se (130.236.30.131) in
the directory pub/lincks.
