


monitor(l)                LINCKS System                monitor(l)



NAME
     monitor - LINCKS database monitor

SYNOPSIS
     monitor [ -d ] database-dir

DESCRIPTION
     The _m_o_n_i_t_o_r program is responsible for the management of the
     LINCKS  database  files.  It  starts up the _n_e_t_s_e_r_v process,
     reads and writes in the various database files,  and  regis-
     ters the appropriate functions with the RPC service package.
     There is one _m_o_n_i_t_o_r per database.  It has several RPC func-
     tions  available  that  are  called  by  the database server
     processes (_d_b_s) to retrieve information  on  where  database
     information  is  stored.  The  _m_o_n_i_t_o_r  program itself never
     touches the contents of  the  data  files,  although  it  is
     responsible  for  creating  new data and molecule files when
     the  need  arises  (the  current  files  get   too   large).
     _d_a_t_a_b_a_s_e-_d_i_r  is  a full path name specifying which database
     to run.

     A user should never have to manually start this program, but
     rather   the  monitor  should  be  start  with  _l_i_n_c_k_s  (see
     lincks(l)).

OPTIONS
     -d   Run the monitor in debug mode.

     database-dir
          The directory where the database  files  reside.   This
          argument is required.

FILES
     DBDIR/.lincksrc
          Database Configuration File.

     LOGDIR/monitor.log
          Log  file  for  error  messages.   LOGDIR  is  set   in
          DBDIR/.lincksrc.

     /tmp/lincks.log
          Last Resort log file if LOGDIR doesn't exist  or  isn't
          writable.

SEE ALSO
     dbs(l), lincks(l), netserv(l)

DIAGNOSTICS
     We hope that the information logged in _m_o_n_i_t_o_r._l_o_g  will  be
     useful in diagnosing any problems.





IISLAB                Last change: 5/19/94                      1






monitor(l)                LINCKS System                monitor(l)



BUGS
     No  known  bugs.   Please  report  all   bugs   to   lincks-
     bugs@ida.liu.se.   Please  include  a description of how you
     can reproduce the bug and the output of either `dbx  monitor
     core' or `gdb monitor core' if possible.

COPYRIGHT
     Copyright (C) 1993, 1994 Lin Padgham, Ralph Ronnquist

     The collective LINCKS programs are free  software;  you  can
     redistribute  them and/or modify them under the terms of the
     GNU General Public License as published by the Free Software
     Foundation, version 2.

     The collective LINCKS programs are distributed in  the  hope
     that  they will be useful, but WITHOUT ANY WARRANTY; without
     even the implied warranty of MERCHANTABILITY or FITNESS  FOR
     A  PARTICULAR  PURPOSE.   See the GNU General Public License
     for more details.

     You should have received a copy of the  GNU  General  Public
     License  along with the LINCKS system; see the file COPYING.
     If not, write to the Free Software Foundation, 675 Mass Ave,
     Cambridge, MA 02139, USA.

AVAILABILITY
     The most recently released version of the LINCKS  system  is
     always  available  for  anonymous  ftp  from  ftp.ida.liu.se
     (130.236.30.131) in the directory pub/lincks.


























IISLAB                Last change: 5/19/94                      2



