


dbpasswd(l)               LINCKS System               dbpasswd(l)



NAME
     dbpasswd - change a password for a user of the LINCKS system


SYNOPSIS
     dbpasswd [-s] [-d _d_a_t_a_b_a_s_e-_d_i_r_e_c_t_o_r_y] username

DESCRIPTION
     The _d_b_p_a_s_s_w_d program is used to change  the  password  of  a
     current user of the LINCKS database system.


OPTIONS
     -d _d_a_t_a_b_a_s_e-_d_i_r_e_c_t_o_r_y
          the path to the directory holding  the  database  files
          for  the  database.  If not given, _d_b_p_a_s_s_w_d will try to
          use the environment variable LINCKSDBDIR.  This option,
          however, will override LINCKSDBDIR.

     -s   silent operation.  No output will be sent to stdout  or
          stderr unless it is a serious error condition.

     username
          This is not  optional.   The  username  of  the  person
          changing his/her password.


DIAGNOSTICS
     Spits out a bit of information when there is  an  unrecover-
     able error condition.  The diagnostics should be self expla-
     natory.

BUGS
     No  known  bugs.   Please  report  all   bugs   to   lincks-
     bugs@ida.liu.se.   Please  include  a description of how you
     can reproduce the bug and the output of either `dbx dbpasswd
     core' or `gdb dbpasswd core' if possible.

COPYRIGHT
     Copyright (C) 1993, 1994 Martin Sjolin

     The collective LINCKS programs are free  software;  you  can
     redistribute  them and/or modify them under the terms of the
     GNU General Public License as published by the Free Software
     Foundation, version 2.

     The collective LINCKS programs are distributed in  the  hope
     that  they will be useful, but WITHOUT ANY WARRANTY; without
     even the implied warranty of MERCHANTABILITY or FITNESS  FOR
     A  PARTICULAR  PURPOSE.   See the GNU General Public License
     for more details.




IISLAB                Last change: 5/19/94                      1






dbpasswd(l)               LINCKS System               dbpasswd(l)



     You should have received a copy of the  GNU  General  Public
     License  along with the LINCKS system; see the file COPYING.
     If not, write to the Free Software Foundation, 675 Mass Ave,
     Cambridge, MA 02139, USA.

AVAILABILITY
     The most recently released version of the LINCKS  system  is
     always  available  for  anonymous  ftp  from  ftp.ida.liu.se
     (130.236.30.131) in the directory pub/lincks.














































IISLAB                Last change: 5/19/94                      2



