


dbroot(l)                 LINCKS System                 dbroot(l)



NAME
     dbroot - initialize a LINCKS database by creating  an  empty
     database root node

SYNOPSIS
     dbroot _d_a_t_a_b_a_s_e-_d_i_r_e_c_t_o_r_y

DESCRIPTION
     The _d_b_r_o_o_t program is used to create the root  node  for  an
     empty database.

     _d_b_r_o_o_t is _D_E_S_T_R_U_C_T_I_V_E!  It will destroy whatever  root  node
     is already in the database if it exists.  Unless you want to
     destroy the contents of a database, don't ever run  this  on
     anything except an empty database.

     If you want to create a new, empty database, the  steps  are
     as follows:

        After choosing your database directory (DBDIR) and confi-
        guring  the  database (by editing a file ._l_i_n_c_k_s_r_c in the
        manner detailed in  installation  documentation),  create
        three empty files called _i_n_d_e_x, _1._d_a_t, and _1._m_o_l:

             touch index 1.dat 1.mol

        Create a file _d_a_t_a._n_a_m_e_s with one line in  it  (ONLY  one
        line):

             1.dat

        Create a file _m_o_l_e_c_u_l_e._n_a_m_e_s with one line  in  it  (ONLY
        one line):

             1.mol

        Create a file _p_a_s_s_w_d with one line in it (ONLY one line):

             lincks   0

        This is the entry for the user _l_i_n_c_k_s who is user 0. Make
        sure this file is only readble by the database owner.

        Set the password for user lincks using the _d_b_p_a_s_s_w_d  pro-
        gram by:

             dbpasswd -d . lincks

        and answer  _h_a_r_g_l_e  twice  (see  also  dbpasswd(l)).   Of
        course  if  you are running with clear text password, you
        can simply add the  password  _h_a_r_g_l_e  when  creating  the
        file.



IISLAB                Last change: 5/27/94                      1






dbroot(l)                 LINCKS System                 dbroot(l)



        Create a file  _g_r_o_u_p_s with  one  line  in  it  (ONLY  one
        line):

             0 0*

        This line means that user 0 is in group 0.   The  asterix
        marks the end of the line.

        Start the database servers (see also lincks(l)):

             lincks -s .


        Run  _d_b_r_o_o_t on the database, which will create the system
        root  and prepare the database to be loaded properly with
        _t_2_l_i_n_c_k_s files that you might have.

             dbroot .


        You will then have to log in as user _l_i_n_c_k_s and  password
        _h_a_r_g_l_e at which point the process will be carried out and
        the program will exit.  The database is ready to load.

OPTIONS
     _d_a_t_a_b_a_s_e-_d_i_r_e_c_t_o_r_y
          the path to the directory holding  the  database  files
          for the database to be initialized.

DIAGNOSTICS
     Prints out the contents of the root node  after  initializa-
     tion.

BUGS
     No  known  bugs.   Please  report  all   bugs   to   lincks-
     bugs@ida.liu.se.   Please  include  a description of how you
     can reproduce the bug and the output of either  `dbx  dbroot
     core' or `gdb dbroot core' if possible.

COPYRIGHT
     Copyright (C) 1993, 1994 Lin Padgham, Ralph Ronnquist

     The collective LINCKS programs are free  software;  you  can
     redistribute  them and/or modify them under the terms of the
     GNU General Public License as published by the Free Software
     Foundation, version 2.

     The collective LINCKS programs are distributed in  the  hope
     that  they will be useful, but WITHOUT ANY WARRANTY; without
     even the implied warranty of MERCHANTABILITY or FITNESS  FOR
     A  PARTICULAR  PURPOSE.   See the GNU General Public License
     for more details.



IISLAB                Last change: 5/27/94                      2






dbroot(l)                 LINCKS System                 dbroot(l)



     You should have received a copy of the  GNU  General  Public
     License  along with the LINCKS system; see the file COPYING.
     If not, write to the Free Software Foundation, 675 Mass Ave,
     Cambridge, MA 02139, USA.

AVAILABILITY
     The most recently released version of the LINCKS  system  is
     always  available  for  anonymous  ftp  from  ftp.ida.liu.se
     (130.236.30.131) in the directory pub/lincks.














































IISLAB                Last change: 5/27/94                      3



