


dbdump(l)                 LINCKS System                 dbdump(l)



NAME
     dbdump - Create a _t_2_l_i_n_c_k_s dump file of LINCKS database.

SYNOPSIS
     dbdump [ -h ] [ -u _u_s_e_r_n_a_m_e -p _p_a_s_s_w_o_r_d ] [ -f _o_u_t_f_i_l_e  ]  [
     -d _m_a_x_d_e_p_t_h ] database-dir

DESCRIPTION
     The  _d_b_d_u_m_p  program  traverses  the  database  _d_b_d_i_r  in  a
     breadth-first traversal down to _m_a_x_d_e_p_t_h level, and produces
     a _t_2_l_i_n_c_k_s-style textual dump of the  database  contents  to
     either  a  file or stdout.  In this way, whole databases can
     be saved as a file and  loaded  into  a  different  database
     using  _t_2_l_i_n_c_k_s. If the database contains binary information
     such as images, extra files might be  generated  which  con-
     tains the binary values (images).


OPTIONS
     -h   This option prints out a usage and version message.

     -u _u_s_e_r_n_a_m_e -p _p_a_s_s_w_o_r_d
          These options allow you to give your username and pass-
          word  on the command-line rather than logging in in the
          normal way.

     -f _o_u_t_f_i_l_e
          This options specifies where to write the  output.   If
          not given, stdout will be used.

     -d _m_a_x_d_e_p_t_h
          Specifies the depth of the traversal.  The  default  is
          to traverse through the entire database.

     database-dir
          This option must be present if the environment variable
          LINCKSDBDIR  is  not  set.   It specifies the directory
          holding the database files.   If  LINCKSDBDIR  is  set,
          this option will override it.

ENVIRONMENT
     _L_I_N_C_K_S_D_B_D_I_R
          specifies the default LINCKS database directory.

SEE ALSO
     t2lincks(l), lincks(l), xlincks(l)

BUGS
     No  known  bugs.  Please  report   all   bugs   to   lincks-
     bugs@ida.liu.se.   Please  include  a description of how you
     can reproduce the bug and the output of either  `dbx  dbdump
     core' or `gdb dbdump core' if possible.



IISLAB                Last change: 5/27/94                      1






dbdump(l)                 LINCKS System                 dbdump(l)



COPYRIGHT
     Copyright (C) 1993, 1994 Lin Padgham, Ralph Ronnquist

     The collective LINCKS programs are free  software;  you  can
     redistribute  them and/or modify them under the terms of the
     GNU General Public License as published by the Free Software
     Foundation, version 2.

     The collective LINCKS programs are distributed in  the  hope
     that  they will be useful, but WITHOUT ANY WARRANTY; without
     even the implied warranty of MERCHANTABILITY or FITNESS  FOR
     A  PARTICULAR  PURPOSE.   See the GNU General Public License
     for more details.

     You should have received a copy of the  GNU  General  Public
     License  along with the LINCKS system; see the file COPYING.
     If not, write to the Free Software Foundation, 675 Mass Ave,
     Cambridge, MA 02139, USA.

AVAILABILITY
     The most recently released version of the LINCKS  system  is
     always  available  for  anonymous  ftp  from  ftp.ida.liu.se
     (130.236.30.131) in the directory pub/lincks.
































IISLAB                Last change: 5/27/94                      2



