


dbs(l)                    LINCKS System                    dbs(l)



NAME
     dbs - LINCKS database server

SYNOPSIS
     dbs [ -d ] [ -o ] [ -h _h_o_s_t_n_a_m_e ] dbdir uid username fd

DESCRIPTION
     _d_b_s is the LINCKS database client server. It is  spawned  by
     the  net server process (_n_e_t_s_e_r_v) when a user logs in (using
     xlincks(1)) to  the  database.   From  that  point  on,  the
     workspace  communicates  with  the  _d_b_s, which does the low-
     level database activity -- storage, retrieval, etc.

     There is only one _m_o_n_i_t_o_r and _n_e_t_s_e_r_v per database, and  one
     _d_b_s per user process (client).

     As a general rule, the user should never have to start a _d_b_s
     process.   Rather,  the _d_b_s is started by the _n_e_t_s_e_r_v, which
     is usually started by _l_i_n_c_k_s.

OPTIONS
     -d   Run _d_b_s in debug mode.  This  is  the  default.   Debug
          output is written to log files.

     -h _h_o_s_t_n_a_m_e
          Name of the machine running the database servers (_m_o_n_i_-
          _t_o_r and _n_e_t_s_e_r_v).

     -o   The _d_b_s handles out-band data to the client differently
          (to avoid a bug in a few TCP implementations).

     dbdir
          The path to the database directory.

     uid  The user identification number of the user starting the
          _d_b_s process.

     username
          The name of the user starting the _d_b_s process.

     fd   The file descriptor (socket number) used for communica-
          tion.

     The last four arguments are required.

FILES
     DBDIR/.lincksrc
          Database Configuration File.

     DBDIR/ITD*
          Interface Table Dump files.  Can be removed safely.




IISLAB                Last change: 5/27/94                      1






dbs(l)                    LINCKS System                    dbs(l)



     LOGDIR/dbs.log
          Log file for log and error messages.

     /tmp/lincks.log
          Last effort log file.

SEE ALSO
     netserv(l), monitor(l), lincks(l), xlincks(1), dbstat(1)

DIAGNOSTICS
     All logging is done to the file _d_b_s._l_o_g in the LOGDIR speci-
     fied in the ._l_i_n_c_k_s_r_c.


BUGS
     No  known  bugs.   Please  report  all   bugs   to   lincks-
     bugs@ida.liu.se.   Please  include  a description of how you
     can reproduce the bug and the  output  of  either  `dbx  dbs
     core' or `gdb dbs core' if possible.

COPYRIGHT
     Copyright (C) 1993, 1994 Lin Padgham, Ralph Ronnquist

     The collective LINCKS programs are free  software;  you  can
     redistribute  them and/or modify them under the terms of the
     GNU General Public License as published by the Free Software
     Foundation, version 2.

     The collective LINCKS programs are distributed in  the  hope
     that  they will be useful, but WITHOUT ANY WARRANTY; without
     even the implied warranty of MERCHANTABILITY or FITNESS  FOR
     A  PARTICULAR  PURPOSE.   See the GNU General Public License
     for more details.

     You should have received a copy of the  GNU  General  Public
     License  along with the LINCKS system; see the file COPYING.
     If not, write to the Free Software Foundation, 675 Mass Ave,
     Cambridge, MA 02139, USA.

AVAILABILITY
     The most recently released version of the LINCKS  system  is
     always  available  for  anonymous  ftp  from  ftp.ida.liu.se
     (130.236.30.131) in the directory pub/lincks.












IISLAB                Last change: 5/27/94                      2



