


lincks(l)                 LINCKS System                 lincks(l)



NAME
     lincks - control program for LINCKS  (Linkoping  Intelligent
     Communication of Knowledge System)

SYNOPSIS
     lincks [ -d ] [ -h _h_o_s_t_n_a_m_e ] [ -k | -r | -s ] _d_a_t_a_b_a_s_e-_d_i_r

DESCRIPTION
     _l_i_n_c_k_s is used to send kill or restart commands to the _m_o_n_i_-
     _t_o_r, and also to start/stop the entire LINCKS system.

OPTIONS
     -d   Run _l_i_n_c_k_s in debug mode.

     -h _h_o_s_t_n_a_m_e
          Host on which the LINCKS system is running.

     -k   Kill the monitor, and thereby stop the LINCKS system.

     -r   Restart the monitor, thereby restarting the LINCKS sys-
          tem.

     -s   Start the LINCKS system.

     _d_a_t_a_b_a_s_e-_d_i_r
          The directory with the  database  files  in  it.   This
          argument is required.

FILES
     DBDIR/.lincksrc
          Database Configuration File.

     LOGDIR
          Directory with logfiles for  log  and  error  messages.
          This    is    defined   in   the   configuration   file
          DBDIR/.lincksrc.

SEE ALSO
     dbroot(l), dbs(l), netserv(l), monitor(l)

DIAGNOSTICS
     Configuration failed: likely bad directory
          The _d_a_t_a_b_a_s_e-_d_i_r you gave on the command-line is not  a
          database.

     RPC-call failed
          RPC failed to talk  correctly  to  the  monitor.   It's
          likely  you're  not  on  the  machine  where the server
          software is running.

     Starting monitor
          Initiating call to _m_o_n_i_t_o_r.



IISLAB                Last change: 5/19/94                      1






lincks(l)                 LINCKS System                 lincks(l)



BUGS
     No  known  bugs.   Please  report  all   bugs   to   lincks-
     bugs@ida.liu.se.   Please  include  a description of how you
     can reproduce the bug and the output of either  `dbx  lincks
     core' or `gdb lincks core' if possible.

COPYRIGHT
     Copyright (C) 1993, 1994 Lin Padgham, Ralph Ronnquist

     The collective LINCKS programs are free  software;  you  can
     redistribute  them and/or modify them under the terms of the
     GNU General Public License as published by the Free Software
     Foundation, version 2.

     The collective LINCKS programs are distributed in  the  hope
     that  they will be useful, but WITHOUT ANY WARRANTY; without
     even the implied warranty of MERCHANTABILITY or FITNESS  FOR
     A  PARTICULAR  PURPOSE.   See the GNU General Public License
     for more details.

     You should have received a copy of the  GNU  General  Public
     License  along with the LINCKS system; see the file COPYING.
     If not, write to the Free Software Foundation, 675 Mass Ave,
     Cambridge, MA 02139, USA.

AVAILABILITY
     The most recently released version of the LINCKS  system  is
     always  available  for  anonymous  ftp  from  ftp.ida.liu.se
     (130.236.30.131) in the directory pub/lincks.


























IISLAB                Last change: 5/19/94                      2



