.\" 
.\" Linkoping Intelligent Communication of Knowledge System (LINCKS)
.\"      Copyright (C) 1993, 1994 Lin Padgham, Ralph Rönnquist
.\"       Department of Computer and Information Sciences
.\"		University of Linkoping, Sweden
.\"		    581 83 Linkoping, Sweden
.\"		       lincks@ida.liu.se
.\"
.\" These collective LINCKS programs are free software; you can 
.\" redistribute them and/or modify them under the terms of the GNU
.\" General Public License as published by the Free Software Foundation,
.\" version 2 of the License.
.\"
.\" These programs are distributed in the hope that they will be useful,
.\" but WITHOUT ANY WARRANTY; without even the implied warranty of
.\" MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
.\" GNU General Public License for more details.
.\"
.\" You should have received a copy of the GNU General Public License
.\" along with the programs; if not, write to the Free Software
.\" Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
.\"
.\" dbdump man page
.\" author: David Partain
.\" version:  @(#)dbdump.l	1.9 5/27/94
.\"
.TH dbdump l "5/27/94" IISLAB "LINCKS System"
.SH NAME
dbdump - Create a \fIt2lincks\fR dump file of LINCKS database.
.SH SYNOPSIS
.B dbdump
[
.B \-h
]
[
.B \-u \fIusername\fR \-p \fIpassword\fR
]
[
.B \-f \fIoutfile\fR
]
[
.B \-d \fImaxdepth\fR
]
.B database\-dir
.SH DESCRIPTION
The \fIdbdump\fR program traverses the database \fIdbdir\fR in a
breadth-first traversal down to \fImaxdepth\fR level, and produces a
\fIt2lincks\fR-style textual dump of the database contents to either a
file or stdout.  In this way, whole databases can be saved as a file and
loaded into a different database using \fIt2lincks\fR. If the database
contains binary information such as images, extra files might be
generated which contains the binary values (images).

.SH OPTIONS
.TP
.B \-h
This option prints out a usage and version message.
.TP
.B \-u \fIusername\fR \-p \fIpassword\fR
These options allow you to give your username and password on the
command-line rather than logging in in the normal way.
.TP
.B \-f \fIoutfile\fR
This options specifies where to write the output.  If not given, stdout
will be used.
.TP
.B \-d \fImaxdepth\fR
Specifies the depth of the traversal.  The default is to traverse
through the entire database.
.TP
.B database\-dir
This option must be present if the environment variable LINCKSDBDIR
is not set.  It specifies the directory holding the database files.  If
LINCKSDBDIR is set, this option will override it.
.SH ENVIRONMENT
.TP
.B \fILINCKSDBDIR\fR
specifies the default LINCKS database directory.
.SH SEE ALSO
t2lincks(l), lincks(l), xlincks(l)
.SH BUGS
No known bugs. Please report all bugs to lincks-bugs@ida.liu.se.
Please include a description of how you can reproduce the bug and the
output of either `dbx dbdump core' or `gdb dbdump core' if possible.
.SH COPYRIGHT
Copyright (C) 1993, 1994 Lin Padgham, Ralph Ronnquist
.LP
The collective LINCKS programs are free software; you can redistribute
them and/or modify them under the terms of the GNU General Public
License as published by the Free Software Foundation, version 2.
.LP
The collective LINCKS programs are distributed in the hope that they
will be useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
the GNU General Public License for more details.
.LP
You should have received a copy of the GNU General Public License along
with the LINCKS system; see the file COPYING.  If not, write to the
Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
.SH AVAILABILITY
The most recently released version of the LINCKS system is always
available for anonymous ftp from ftp.ida.liu.se (130.236.30.131) in
the directory pub/lincks.
